eeptools: Evaluation of educational policy tools

eeptoolsR Documentation

Evaluation of educational policy tools

Description

Make common tasks for educational evaluation easier to do!

Details

This package has a number of useful shortcuts for common tasks. It includes some themes for ggplot2 plots, processing arbitrary text files of data, calculating student characteristics, and finding thresholds within vectors. Future development work will include methods for tuning and evaluating early warning system models.

Author(s)

Jared E. Knowles

See Also

Useful links:

Examples

gender<-c("M","M","M","F","F","F")
statamode(gender)
statamode(gender[1:5])

missing_data<-c(NA,NA,NA)
max_mis(missing_data)

makenum(gender)
gender <- factor(gender)
defac(gender)

eeptools documentation built on June 23, 2026, 1:06 a.m.