theme_dpi: a defunct ggplot2 theme developed for PDF and PNG for use at...

theme_dpiR Documentation

a defunct ggplot2 theme developed for PDF and PNG for use at the Wisconsin Department of Public Instruction

Description

This was a custom ggplot2 theme developed for the Wisconsin Department of Public Instruction. This function is now defunct.

Usage

theme_dpi(base_size = 16, base_family = "")

Arguments

base_size

numeric, specify the font size as a numeric value, default is 16

base_family

character, specify the font family, this value is optional

Details

All values are optional

Value

This function is defunct.

Deprecation

Defunct as of eeptools 1.3.0 (deprecated since 1.2.x). Use theme_bw instead.

Author(s)

Jared E. Knowles

See Also

theme_bw from the ggplot2 package.


eeptools documentation built on June 23, 2026, 1:06 a.m.