theme_dpi_map2: an alternate defunct ggplot2 theme developed for PDF or SVG...

View source: R/theme_dpi.R

theme_dpi_map2R Documentation

an alternate defunct ggplot2 theme developed for PDF or SVG maps

Description

This was an alternate ggplot2 theme developed for the Wisconsin Department of Public Instruction for making PDF maps. This function is now defunct.

Usage

theme_dpi_map2(base_size = 14, base_family = "")

Arguments

base_size

numeric, specify the font size, default is 14

base_family

character, specify the font family, this value is optional

Value

This function is defunct.

Deprecation

Defunct as of eeptools 1.3.0 (deprecated since 1.2.x). Use theme_bw instead.

Author(s)

Jared E. Knowles

See Also

theme_bw from the ggplot2 package.


eeptools documentation built on June 23, 2026, 1:06 a.m.