| eeptools | R Documentation |
Make common tasks for educational evaluation easier to do!
This package has a number of useful shortcuts for common tasks. It includes some themes for ggplot2 plots, processing arbitrary text files of data, calculating student characteristics, and finding thresholds within vectors. Future development work will include methods for tuning and evaluating early warning system models.
Jared E. Knowles
Useful links:
gender<-c("M","M","M","F","F","F")
statamode(gender)
statamode(gender[1:5])
missing_data<-c(NA,NA,NA)
max_mis(missing_data)
makenum(gender)
gender <- factor(gender)
defac(gender)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.