| theme_dpi_map | R Documentation |
This was a ggplot2 theme developed for the Wisconsin Department of Public Instruction for making PDF maps. This function is now defunct.
theme_dpi_map(base_size = 14, base_family = "")
base_size |
numeric, specify the font size, default is 14 |
base_family |
character, specify the font family, this value is optional |
This function is defunct.
Defunct as of eeptools 1.3.0 (deprecated since 1.2.x). Use
theme_bw instead.
Jared E. Knowles
theme_bw from the ggplot2 package.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.